==> libksysguard-5.27.9-aarch64-1.txz: usr/lib64/cmake/KSysGuard/KSysGuardLibraryTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KSysGuard::Formatter" for configuration "Release"
set_property(TARGET KSysGuard::Formatter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::Formatter PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::CoreAddons;KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKSysGuardFormatter.so.5.27.9"
  IMPORTED_SONAME_RELEASE "libKSysGuardFormatter.so.1"
  )

list(APPEND _cmake_import_check_targets KSysGuard::Formatter )
list(APPEND _cmake_import_check_files_for_KSysGuard::Formatter "${_IMPORT_PREFIX}/lib64/libKSysGuardFormatter.so.5.27.9" )

# Import target "KSysGuard::LsofUi" for configuration "Release"
set_property(TARGET KSysGuard::LsofUi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::LsofUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/liblsofui.so.5.27.9"
  IMPORTED_SONAME_RELEASE "liblsofui.so.9"
  )

list(APPEND _cmake_import_check_targets KSysGuard::LsofUi )
list(APPEND _cmake_import_check_files_for_KSysGuard::LsofUi "${_IMPORT_PREFIX}/lib64/liblsofui.so.5.27.9" )

# Import target "KSysGuard::ProcessCore" for configuration "Release"
set_property(TARGET KSysGuard::ProcessCore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::ProcessCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n;KF5::AuthCore;KF5::CoreAddons;KF5::Service"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libprocesscore.so.5.27.9"
  IMPORTED_SONAME_RELEASE "libprocesscore.so.9"
  )

list(APPEND _cmake_import_check_targets KSysGuard::ProcessCore )
list(APPEND _cmake_import_check_files_for_KSysGuard::ProcessCore "${_IMPORT_PREFIX}/lib64/libprocesscore.so.5.27.9" )

# Import target "KSysGuard::ProcessUi" for configuration "Release"
set_property(TARGET KSysGuard::ProcessUi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::ProcessUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n;KF5::WindowSystem;KF5::AuthCore;KF5::Completion;KF5::ConfigWidgets;KF5::WidgetsAddons;KF5::IconThemes;KF5::JobWidgets;KF5::GlobalAccel;KF5::Service;KF5::KIOGui"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libprocessui.so.5.27.9"
  IMPORTED_SONAME_RELEASE "libprocessui.so.9"
  )

list(APPEND _cmake_import_check_targets KSysGuard::ProcessUi )
list(APPEND _cmake_import_check_files_for_KSysGuard::ProcessUi "${_IMPORT_PREFIX}/lib64/libprocessui.so.5.27.9" )

# Import target "KSysGuard::Sensors" for configuration "Release"
set_property(TARGET KSysGuard::Sensors APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::Sensors PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n;KSysGuard::SystemStats"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKSysGuardSensors.so.5.27.9"
  IMPORTED_SONAME_RELEASE "libKSysGuardSensors.so.1"
  )

list(APPEND _cmake_import_check_targets KSysGuard::Sensors )
list(APPEND _cmake_import_check_files_for_KSysGuard::Sensors "${_IMPORT_PREFIX}/lib64/libKSysGuardSensors.so.5.27.9" )

# Import target "KSysGuard::SensorFaces" for configuration "Release"
set_property(TARGET KSysGuard::SensorFaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::SensorFaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n;KF5::Package;KF5::ConfigQml;KF5::Solid"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKSysGuardSensorFaces.so.5.27.9"
  IMPORTED_SONAME_RELEASE "libKSysGuardSensorFaces.so.1"
  )

list(APPEND _cmake_import_check_targets KSysGuard::SensorFaces )
list(APPEND _cmake_import_check_files_for_KSysGuard::SensorFaces "${_IMPORT_PREFIX}/lib64/libKSysGuardSensorFaces.so.5.27.9" )

# Import target "KSysGuard::SignalPlotter" for configuration "Release"
set_property(TARGET KSysGuard::SignalPlotter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::SignalPlotter PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KSysGuard::ProcessCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libksignalplotter.so.5.27.9"
  IMPORTED_SONAME_RELEASE "libksignalplotter.so.9"
  )

list(APPEND _cmake_import_check_targets KSysGuard::SignalPlotter )
list(APPEND _cmake_import_check_files_for_KSysGuard::SignalPlotter "${_IMPORT_PREFIX}/lib64/libksignalplotter.so.5.27.9" )

# Import target "KSysGuard::SysGuard" for configuration "Release"
set_property(TARGET KSysGuard::SysGuard APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::SysGuard PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n;KF5::CoreAddons;KSysGuard::ProcessCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libksgrd.so.5.27.9"
  IMPORTED_SONAME_RELEASE "libksgrd.so.9"
  )

list(APPEND _cmake_import_check_targets KSysGuard::SysGuard )
list(APPEND _cmake_import_check_files_for_KSysGuard::SysGuard "${_IMPORT_PREFIX}/lib64/libksgrd.so.5.27.9" )

# Import target "KSysGuard::SystemStats" for configuration "Release"
set_property(TARGET KSysGuard::SystemStats APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::SystemStats PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKSysGuardSystemStats.so.5.27.9"
  IMPORTED_SONAME_RELEASE "libKSysGuardSystemStats.so.1"
  )

list(APPEND _cmake_import_check_targets KSysGuard::SystemStats )
list(APPEND _cmake_import_check_files_for_KSysGuard::SystemStats "${_IMPORT_PREFIX}/lib64/libKSysGuardSystemStats.so.5.27.9" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libksysguard-5.27.12-aarch64-1.txz: usr/lib64/cmake/KSysGuard/KSysGuardLibraryTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KSysGuard::Formatter" for configuration "Release"
set_property(TARGET KSysGuard::Formatter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::Formatter PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::CoreAddons;KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKSysGuardFormatter.so.5.27.12"
  IMPORTED_SONAME_RELEASE "libKSysGuardFormatter.so.1"
  )

list(APPEND _cmake_import_check_targets KSysGuard::Formatter )
list(APPEND _cmake_import_check_files_for_KSysGuard::Formatter "${_IMPORT_PREFIX}/lib64/libKSysGuardFormatter.so.5.27.12" )

# Import target "KSysGuard::LsofUi" for configuration "Release"
set_property(TARGET KSysGuard::LsofUi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::LsofUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/liblsofui.so.5.27.12"
  IMPORTED_SONAME_RELEASE "liblsofui.so.9"
  )

list(APPEND _cmake_import_check_targets KSysGuard::LsofUi )
list(APPEND _cmake_import_check_files_for_KSysGuard::LsofUi "${_IMPORT_PREFIX}/lib64/liblsofui.so.5.27.12" )

# Import target "KSysGuard::ProcessCore" for configuration "Release"
set_property(TARGET KSysGuard::ProcessCore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::ProcessCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n;KF5::AuthCore;KF5::CoreAddons;KF5::Service"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libprocesscore.so.5.27.12"
  IMPORTED_SONAME_RELEASE "libprocesscore.so.9"
  )

list(APPEND _cmake_import_check_targets KSysGuard::ProcessCore )
list(APPEND _cmake_import_check_files_for_KSysGuard::ProcessCore "${_IMPORT_PREFIX}/lib64/libprocesscore.so.5.27.12" )

# Import target "KSysGuard::ProcessUi" for configuration "Release"
set_property(TARGET KSysGuard::ProcessUi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::ProcessUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n;KF5::WindowSystem;KF5::AuthCore;KF5::ConfigWidgets;KF5::WidgetsAddons;KF5::IconThemes;KF5::JobWidgets;KF5::GlobalAccel;KF5::Service;KF5::KIOGui"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libprocessui.so.5.27.12"
  IMPORTED_SONAME_RELEASE "libprocessui.so.9"
  )

list(APPEND _cmake_import_check_targets KSysGuard::ProcessUi )
list(APPEND _cmake_import_check_files_for_KSysGuard::ProcessUi "${_IMPORT_PREFIX}/lib64/libprocessui.so.5.27.12" )

# Import target "KSysGuard::Sensors" for configuration "Release"
set_property(TARGET KSysGuard::Sensors APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::Sensors PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n;KSysGuard::SystemStats"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKSysGuardSensors.so.5.27.12"
  IMPORTED_SONAME_RELEASE "libKSysGuardSensors.so.1"
  )

list(APPEND _cmake_import_check_targets KSysGuard::Sensors )
list(APPEND _cmake_import_check_files_for_KSysGuard::Sensors "${_IMPORT_PREFIX}/lib64/libKSysGuardSensors.so.5.27.12" )

# Import target "KSysGuard::SensorFaces" for configuration "Release"
set_property(TARGET KSysGuard::SensorFaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::SensorFaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n;KF5::Package;KF5::ConfigQml;KF5::Solid"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKSysGuardSensorFaces.so.5.27.12"
  IMPORTED_SONAME_RELEASE "libKSysGuardSensorFaces.so.1"
  )

list(APPEND _cmake_import_check_targets KSysGuard::SensorFaces )
list(APPEND _cmake_import_check_files_for_KSysGuard::SensorFaces "${_IMPORT_PREFIX}/lib64/libKSysGuardSensorFaces.so.5.27.12" )

# Import target "KSysGuard::SignalPlotter" for configuration "Release"
set_property(TARGET KSysGuard::SignalPlotter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::SignalPlotter PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KSysGuard::ProcessCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libksignalplotter.so.5.27.12"
  IMPORTED_SONAME_RELEASE "libksignalplotter.so.9"
  )

list(APPEND _cmake_import_check_targets KSysGuard::SignalPlotter )
list(APPEND _cmake_import_check_files_for_KSysGuard::SignalPlotter "${_IMPORT_PREFIX}/lib64/libksignalplotter.so.5.27.12" )

# Import target "KSysGuard::SysGuard" for configuration "Release"
set_property(TARGET KSysGuard::SysGuard APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::SysGuard PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n;KF5::CoreAddons;KSysGuard::ProcessCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libksgrd.so.5.27.12"
  IMPORTED_SONAME_RELEASE "libksgrd.so.9"
  )

list(APPEND _cmake_import_check_targets KSysGuard::SysGuard )
list(APPEND _cmake_import_check_files_for_KSysGuard::SysGuard "${_IMPORT_PREFIX}/lib64/libksgrd.so.5.27.12" )

# Import target "KSysGuard::SystemStats" for configuration "Release"
set_property(TARGET KSysGuard::SystemStats APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KSysGuard::SystemStats PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKSysGuardSystemStats.so.5.27.12"
  IMPORTED_SONAME_RELEASE "libKSysGuardSystemStats.so.1"
  )

list(APPEND _cmake_import_check_targets KSysGuard::SystemStats )
list(APPEND _cmake_import_check_files_for_KSysGuard::SystemStats "${_IMPORT_PREFIX}/lib64/libKSysGuardSystemStats.so.5.27.12" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
